wrap

Function wrap 

pub fn wrap(text: &str, width: u16) -> Vec<String>
Break text into lines no wider than width.

wrap_spans under one style, flattened back to strings for the callers that have no styles to keep.